#ifndef EXPENSESLIST_H
#define EXPENSESLIST_H

#include <QWidget>
#include <QModelIndex>

class ExpensesList : public QWidget
{
        Q_OBJECT
 public:
        ExpensesList(QWidget *parent = 0);
 signals:
        void newExpenseSelected();
        void expenseDetailsSelected(QModelIndex index);
};
#endif
